# Lab Orchestrator

General Purpose Orchestrator for Scientific Laboratories. It collaborates nicely with the [labscheduler](https://gitlab.com/OpenLabAutomation/lab-automation-packages/lab-scheduler) , SiLA servers and [pythonLab](https://gitlab.com/OpenLabAutomation/lab-automation-packages/pythonLab) as process description language.

The documentation on ow to use those in combination is described [here on git](https://gitlab.com/OpenLabAutomation/adaption-template) and here visualized on a [poster](https://gitlab.com/OpenLabAutomation/data/-/blob/main/slas_poster_annotated.pdf?ref_type=heads) from SLAS 2025.

## Features
The standlone orechstrator comes with a pragmatic web-based GUI running by default on [127.0.0.1:8050](127.0.0.1:8050) and interfaces to include
- a database
- a scheduler
- process description languages

different from the obove recommendations.

## Installation
Run 
``` bash 
    pip install git+https://gitlab.com/OpenLabAutomation/lab-automation-packages/laborchestrator.git 
```
to install the main branch or
``` bash 
    pip install laborchestrator --index-url https://gitlab.com/api/v4/projects/70366855/packages/pypi/simple
```
to install the latest version.


## Usage

``` bash 
    laborchestrator --help 
```